createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
AudioMessage createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
AudioMessage createEmptyInstance() => create();