createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
AudioModel createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
AudioModel createEmptyInstance() => create();