createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
AudioSegment createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
AudioSegment createEmptyInstance() => create();