createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ClassificationResult createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ClassificationResult createEmptyInstance() => create();